@@ -395,11 +395,19 @@ Tcl_Interp *interp;
 {
     ThreadSpecificData *tsdPtr = TCL_TSD_INIT(&dataKey);
     ExpState *esPtr;
+    ExpState *esNextPtr;
+
+    /* Save the nextPtr in a local variable before calling 'exp_close'
+       as 'expStateFree' can be called from it under some
+       circumstances, possibly causing the memory allocator to smash
+       the value in 'esPtr'. - Andreas Kupries
+    */
 
     /* no need to keep things in sync (i.e., tsdPtr, count) since we could only
        be doing this if we're exiting.  Just close everything down. */
 
-    for (esPtr = tsdPtr->firstExpPtr;esPtr;esPtr = esPtr->nextPtr) {
+    for (esPtr = tsdPtr->firstExpPtr;esPtr;esPtr = esNextPtr) {
+        esNextPtr = esPtr->nextPtr;
 	exp_close(interp,esPtr);
     }
 }
